@@ -5,7 +5,6 @@ use overload
   '""'     => sub { shift->join("\n") },
   fallback => 1;
 
-# "Sweet Zombie Jesus!"
 use Exporter 'import';
 use List::Util;
 use Mojo::ByteStream;
@@ -29,21 +28,17 @@ sub each {
 
 sub first {
   my ($self, $cb) = @_;
-  return $self->[0] unless $cb;
-  return List::Util::first { $_ ~~ $cb } @$self;
+  return $cb ? List::Util::first { $_ ~~ $cb } @$self : $self->[0];
 }
 
-# "All right, let's not panic.
-#  I'll make the money by selling one of my livers.
-#  I can get by with one."
 sub grep {
   my ($self, $cb) = @_;
   return $self->new(grep { $_ ~~ $cb } @$self);
 }
 
 sub join {
-  my ($self, $expression) = @_;
-  return Mojo::ByteStream->new(join $expression, map({"$_"} @$self));
+  my ($self, $expr) = @_;
+  return Mojo::ByteStream->new(join $expr, map({"$_"} @$self));
 }
 
 sub map {
@@ -51,8 +46,6 @@ sub map {
   return $self->new(map { $_->$cb } @$self);
 }
 
-# "Facts are meaningless.
-#  You could use facts to prove anything that's even remotely true!"
 sub pluck {
   my ($self, $method, @args) = @_;
   return $self->map(sub { $_->$method(@args) });
@@ -63,9 +56,6 @@ sub reverse {
   return $self->new(reverse @$self);
 }
 
-# "You told Bart to kiss that girl?
-#  Why not encourage him to knock her out and drag her to a cave?
-#  Second base? Oh, Bart is a little too young for that."
 sub shuffle {
   my $self = shift;
   return $self->new(List::Util::shuffle @$self);
@@ -80,12 +70,9 @@ sub slice {
 
 sub sort {
   my ($self, $cb) = @_;
-  return $self->new(sort @$self) unless $cb;
-  return $self->new(sort { $a->$cb($b) } @$self);
+  return $self->new($cb ? sort { $a->$cb($b) } @$self : sort @$self);
 }
 
-# "Christmas is a time when people of all religions come together to worship
-#  Jesus Christ."
 sub uniq {
   my $self = shift;
   my %seen;
