@@ -6,13 +6,12 @@ use Mojo::Util qw(class_to_file class_to_path);
 has description => "Generate Mojolicious application directory structure.\n";
 has usage       => "usage: $0 generate app [NAME]\n";
 
-# "I say, you've damaged our servants quarters... and our servants."
 sub run {
   my ($self, $class) = @_;
   $class ||= 'MyMojoliciousApp';
 
   # Prevent bad applications
-  die <<EOF unless $class =~ /^[A-Z](?:\w|\:\:)+$/;
+  die <<EOF unless $class =~ /^[A-Z](?:\w|::)+$/;
 Your application name has to be a well formed (camel case) Perl module name
 like "MyApp".
 EOF
